@@ -40,7 +40,7 @@ Util::H2O - Hash to Object: turns hashrefs into objects with accessors for keys
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.22';
 # For AUTHOR, COPYRIGHT, AND LICENSE see the bottom of this file
 
 our @EXPORT = qw/ h2o /;  ## no critic (ProhibitAutomaticExportation)
@@ -206,7 +206,9 @@ This option was added in v0.14.
 Whether or not to clean up the generated package when the object is
 destroyed. Defaults to I<false> when C<-class> is specified, I<true>
 otherwise. If this is I<false>, be aware that the packages will stay
-in Perl's symbol table and use memory accordingly.
+in Perl's symbol table and use memory accordingly, and any subs/methods
+in those packages may cause "redefined" warnings if the package
+name is re-used.
 
 As of v0.16, this module will refuse to delete the package if it
 is named C<main>.
@@ -417,7 +419,7 @@ sub h2o {  ## no critic (RequireArgUnpacking, ProhibitExcessComplexity)
 			if ( $arrays && ref eq 'ARRAY' )
 				{ h2o(-arrays,  -lock=>$lock, ($ro?-ro:()), $_) }
 			elsif ( ref eq 'HASH' )
-				{ h2o(-recurse, -lock=>$lock, ($ro?-ro:()), $_) }
+				{ h2o($arrays?-arrays:-recurse, -lock=>$lock, ($ro?-ro:()), $_) }
 		}
 	}
 	my $pack = defined $class ? $class : sprintf('Util::H2O::_%x', $hash+0);
@@ -528,7 +530,7 @@ __END__
 
 If the hash you want to pass to C<h2o> contains keys that are not usable as
 method names, such as keys containing spaces or dashes, you can transform the
-hash before passing it to C<h2o>. There are several ways to do this, including
+hash before passing it to C<h2o>. There are several ways to achieve this, including
 in plain Perl, but one of the easier ways is with C<pairmap> from the core
 module L<List::Util>.
 
